==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ACmplBinop.h <==
// public final class soot.jimple.parser.node.ACmplBinop

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c67574568c9265b0 soot_jimple_parser_node_ACmplBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_ACmplBinop_H_
#define _JC_soot_jimple_parser_node_ACmplBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TCmpl$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ACmplBinop$sub_refs	_jc_soot_jimple_parser_node_ACmplBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ACmplBinop$sub_nonrefs	_jc_soot_jimple_parser_node_ACmplBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmplBinop$refs	_jc_soot_jimple_parser_node_ACmplBinop$refs;
typedef struct _jc_soot_jimple_parser_node_ACmplBinop$nonrefs	_jc_soot_jimple_parser_node_ACmplBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmplBinop$object	_jc_soot_jimple_parser_node_ACmplBinop$object;

typedef const struct _jc_soot_jimple_parser_node_ACmplBinop$vmethods	_jc_soot_jimple_parser_node_ACmplBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ACmplBinop$vtable	_jc_soot_jimple_parser_node_ACmplBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_ACmplBinop$vtype	_jc_soot_jimple_parser_node_ACmplBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ACmplBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *);
extern void _jc_soot_jimple_parser_node_ACmplBinop$method$_init$2c2276b469166449(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *, struct _jc_soot_jimple_parser_node_TCmpl$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ACmplBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ACmplBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *);
extern struct _jc_soot_jimple_parser_node_TCmpl$object *_jc_soot_jimple_parser_node_ACmplBinop$method$getCmpl$e0b8b5f2aa854cf0(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *);
extern void _jc_soot_jimple_parser_node_ACmplBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ACmplBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ACmplBinop$method$setCmpl$21828ffc138d637f(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *, struct _jc_soot_jimple_parser_node_TCmpl$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ACmplBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ACmplBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ACmplBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ACmplBinop$method_info$getCmpl$e0b8b5f2aa854cf0;
extern _jc_method _jc_soot_jimple_parser_node_ACmplBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ACmplBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ACmplBinop$method_info$setCmpl$21828ffc138d637f;
extern _jc_method _jc_soot_jimple_parser_node_ACmplBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ACmplBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *);
	struct _jc_soot_jimple_parser_node_TCmpl$object	*(*getCmpl$e0b8b5f2aa854cf0)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setCmpl$21828ffc138d637f)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *, struct _jc_soot_jimple_parser_node_TCmpl$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ACmplBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_ACmplBinop$vmethods	soot_jimple_parser_node_ACmplBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_ACmplBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ACmplBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmplBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TCmpl$object	*__5fcmpl__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmplBinop$refs {
    _jc_soot_jimple_parser_node_ACmplBinop$sub_refs	soot_jimple_parser_node_ACmplBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmplBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmplBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_ACmplBinop$sub_nonrefs	soot_jimple_parser_node_ACmplBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ACmplBinop$object {
	_jc_soot_jimple_parser_node_ACmplBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ACmplBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_ACmplBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ACmplBinop$vtype _jc_soot_jimple_parser_node_ACmplBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ACmplBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ACmplBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_ACmplBinop_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ACmplBinop.h <==
// public final class soot.jimple.parser.node.ACmplBinop

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c67574568c9265b0 soot_jimple_parser_node_ACmplBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_ACmplBinop_H_
#define _JC_soot_jimple_parser_node_ACmplBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TCmpl$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ACmplBinop$sub_refs	_jc_soot_jimple_parser_node_ACmplBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ACmplBinop$sub_nonrefs	_jc_soot_jimple_parser_node_ACmplBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmplBinop$refs	_jc_soot_jimple_parser_node_ACmplBinop$refs;
typedef struct _jc_soot_jimple_parser_node_ACmplBinop$nonrefs	_jc_soot_jimple_parser_node_ACmplBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmplBinop$object	_jc_soot_jimple_parser_node_ACmplBinop$object;

typedef const struct _jc_soot_jimple_parser_node_ACmplBinop$vmethods	_jc_soot_jimple_parser_node_ACmplBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ACmplBinop$vtable	_jc_soot_jimple_parser_node_ACmplBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_ACmplBinop$vtype	_jc_soot_jimple_parser_node_ACmplBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ACmplBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmplBinop$method$_init$2c2276b469166449(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *, struct _jc_soot_jimple_parser_node_TCmpl$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ACmplBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ACmplBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TCmpl$object *_jc_soot_jimple_parser_node_ACmplBinop$method$getCmpl$e0b8b5f2aa854cf0(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmplBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmplBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmplBinop$method$setCmpl$21828ffc138d637f(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *, struct _jc_soot_jimple_parser_node_TCmpl$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ACmplBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ACmplBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ACmplBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ACmplBinop$method_info$getCmpl$e0b8b5f2aa854cf0;
extern _jc_method _jc_soot_jimple_parser_node_ACmplBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ACmplBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ACmplBinop$method_info$setCmpl$21828ffc138d637f;
extern _jc_method _jc_soot_jimple_parser_node_ACmplBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ACmplBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TCmpl$object	*(*getCmpl$e0b8b5f2aa854cf0)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setCmpl$21828ffc138d637f)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *, struct _jc_soot_jimple_parser_node_TCmpl$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmplBinop$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ACmplBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_ACmplBinop$vmethods	soot_jimple_parser_node_ACmplBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_ACmplBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ACmplBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmplBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TCmpl$object	*__5fcmpl__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmplBinop$refs {
    _jc_soot_jimple_parser_node_ACmplBinop$sub_refs	soot_jimple_parser_node_ACmplBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmplBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmplBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_ACmplBinop$sub_nonrefs	soot_jimple_parser_node_ACmplBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ACmplBinop$object {
	_jc_soot_jimple_parser_node_ACmplBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ACmplBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_ACmplBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ACmplBinop$vtype _jc_soot_jimple_parser_node_ACmplBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ACmplBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ACmplBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_ACmplBinop_H_ */
